@@ -14,18 +14,22 @@ fi
 ver="$1"
 [[ "$ver" == "snap" ]] && ver=$(date -u +%Y%m%d)
 bn="$(basename $(pwd))-${ver}"
-[[ -d "../${bn}" ]] && rm -r "${bn}"
+[[ -d "../${bn}" ]] && rm -r "../${bn}"
+[[ -n "../${bn}.tar.bz2.sig" ]] && rm -r "../${bn}.tar.bz2.sig"
 mkdir "../${bn}" || exit 1
 cp -r * "../${bn}/" || exit 1
 find "../${bn}" -type d -name CVS -exec rm -rf '{}' \; 2>/dev/null
 tar jcf "../${bn}".tar.bz2 "../${bn}" || exit 1
 rm -fr "../${bn}" || exit 1
 du -b "../${bn}".tar.bz2
+gpg -b --use-agent "../${bn}".tar.bz2
 bn="cpuinfo-data-$(date -u +%Y%m%d)"
-[[ -d "../${bn}" ]] && rm -r "${bn}"
+[[ -d "../${bn}" ]] && rm -r "../${bn}"
+[[ -n "../${bn}.tar.bz2.sig" ]] && rm -r "../${bn}.tar.bz2.sig"
 mkdir "../${bn}" || exit 1
 cp -r tests/data*/* "../${bn}/" || exit 1
 find "../${bn}" -type d -name CVS -exec rm -rf '{}' \; 2>/dev/null
 tar jcf "../${bn}".tar.bz2 "../${bn}" || exit 1
 rm -fr "../${bn}" || exit 1
 du -b "../${bn}".tar.bz2
+gpg -b --use-agent "../${bn}".tar.bz2
