@@ -21,13 +21,15 @@
 #ifndef __PROCCPUINFO_H
 #define __PROCCPUINFO_H
 
-typedef struct proccpuinfo {
+typedef struct proccpuinfo {;
+	unsigned short version;
 	char *architecture;
 	char *hardware_platform;
 	double frequency;		/* in MHz */
 	double bogomips;
 	unsigned int cache;		/* in KB  */
 	unsigned int cpus;		/* number of processors */
+	char *cputype;
 } proccpuinfo;
 
 proccpuinfo *proccpuinfo_read();
